@@ -76,16 +76,25 @@ def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, outro_cl
         path_video = None
         pass
     return path_video
-def create_image(list_comp_data,path_img, t=0):
+def create_image(list_comp_data, path_img, t=0):
     arr_comps = []
     for comp_data in list_comp_data:
         comp_data["job_id"] = 1
         comp_data["mf_server"] = "http://api-magicframe.automusic.win/"
-        if comp_data['type'] == "compilation" or comp_data['type'] == "lyric" :
+        if comp_data['type'] == "video":
+            comp_data['c_type'] = 'image'
+        if comp_data['type'] == "compilation" or comp_data['type'] == "lyric":
             continue
-        arr_comps.append(Component.convert(comp_data).make())
 
-    CompositeVideoClip(arr_comps).save_frame(path_img,t)
+        arr_comps.append(Component.convert(comp_data))
+    arr_comps_maked=[]
+    for comp in arr_comps:
+        arr_comps_maked.append(comp.make())
+    CompositeVideoClip(arr_comps_maked).save_frame(path_img, t)
+    for compm in arr_comps_maked:
+        compm.close()
+    for comp in arr_comps:
+        comp.delete_res()
     return path_img
 
 def create_video(list_comp_data, path_video, job_id, mf_server):
@@ -330,6 +339,13 @@ class Component:
         print('get clip')
     def set_bg_clip(self,bg_clip):
         print('set bg clip')
+    def delete_res(self):
+        if hasattr(self,'audio_path') and self.audio_path:
+            utils.remove(self.audio_path)
+        if hasattr(self,'video_path') and self.video_path:
+            utils.remove(self.video_path)
+        if hasattr(self,'image_path') and self.image_path:
+            utils.remove(self.image_path)
     def get_audio(self):
         self.audio_path=None
         self.audio_moviepy=None
@@ -538,6 +554,9 @@ class VideoComp(Component):
         self.kind = "video"
         self.is_intro=False
         self.is_outro=False
+        self.c_type='video' #type get clip
+        if "c_type" in json_data:
+            self.c_type = json_data['c_type']
         if "is_intro" in json_data:
             self.is_intro = json_data['is_intro']
         if "is_outro" in json_data:
@@ -545,7 +564,10 @@ class VideoComp(Component):
         if self.is_canva:
             self.kind = "canva"
     def get_clip(self):
-        if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro and self.md5!="tiktok":
+        if self.c_type == 'image':
+            self.isLoop = False
+            self.isSmoothLoop = False
+        if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro and self.md5 != "tiktok":
             obj = requests.get(self.mf_server+"resource/get-md5/"+self.kind+"/"+self.md5).json()
             if "id" in obj:
                 if "loop_link" in obj and obj['loop_link'] is not None and "gdrive" in obj['loop_link']:
@@ -572,7 +594,7 @@ class VideoComp(Component):
             has_mask = True
         rs = VideoFileClip(self.video_path, audio=not self.isMute, has_mask=has_mask)
         self.real_duration = rs.duration
-        if (self.index == 0 or self.isLoop) and rs.duration < 600: #max 20 mins loop
+        if ((self.index == 0 or self.isLoop) and self.c_type=='video') and rs.duration < 600: #max 20 mins loop
             rs.close()
             self.video_path = create_loop(self.video_path, 600)
             rs = VideoFileClip(self.video_path, audio=not self.isMute, has_mask=has_mask)
